import type { Attachment } from '../../../../decorators/attachment/Attachment';
import type { DidCommMessageRepository } from '../../../../storage';
import type { CredentialFormat, CredentialFormatPayload, CredentialFormatService } from '../../formats';
import type { CredentialFormatSpec } from '../../models';
import type { CredentialExchangeRecord } from '../../repository/CredentialExchangeRecord';
import { V2IssueCredentialMessage, V2OfferCredentialMessage, V2ProposeCredentialMessage, V2RequestCredentialMessage } from './messages';
export declare class CredentialFormatCoordinator<CFs extends CredentialFormat[]> {
    private didCommMessageRepository;
    constructor(didCommMessageRepository: DidCommMessageRepository);
    /**
     * Create a {@link V2ProposeCredentialMessage}.
     *
     * @param options
     * @returns The created {@link V2ProposeCredentialMessage}
     *
     */
    createProposal({ credentialFormats, formatServices, credentialRecord, comment, }: {
        formatServices: CredentialFormatService[];
        credentialFormats: CredentialFormatPayload<CFs, 'createProposal'>;
        credentialRecord: CredentialExchangeRecord;
        comment?: string;
    }): Promise<V2ProposeCredentialMessage>;
    processProposal({ credentialRecord, message, formatServices, }: {
        credentialRecord: CredentialExchangeRecord;
        message: V2ProposeCredentialMessage;
        formatServices: CredentialFormatService[];
    }): Promise<void>;
    acceptProposal({ credentialRecord, credentialFormats, formatServices, comment, }: {
        credentialRecord: CredentialExchangeRecord;
        credentialFormats?: CredentialFormatPayload<CFs, 'acceptProposal'>;
        formatServices: CredentialFormatService[];
        comment?: string;
    }): Promise<V2OfferCredentialMessage>;
    /**
     * Create a {@link V2OfferCredentialMessage}.
     *
     * @param options
     * @returns The created {@link V2OfferCredentialMessage}
     *
     */
    createOffer({ credentialFormats, formatServices, credentialRecord, comment, }: {
        formatServices: CredentialFormatService[];
        credentialFormats: CredentialFormatPayload<CFs, 'createOffer'>;
        credentialRecord: CredentialExchangeRecord;
        comment?: string;
    }): Promise<V2OfferCredentialMessage>;
    processOffer({ credentialRecord, message, formatServices, }: {
        credentialRecord: CredentialExchangeRecord;
        message: V2OfferCredentialMessage;
        formatServices: CredentialFormatService[];
    }): Promise<void>;
    acceptOffer({ credentialRecord, credentialFormats, formatServices, comment, }: {
        credentialRecord: CredentialExchangeRecord;
        credentialFormats?: CredentialFormatPayload<CFs, 'acceptOffer'>;
        formatServices: CredentialFormatService[];
        comment?: string;
    }): Promise<V2RequestCredentialMessage>;
    /**
     * Create a {@link V2RequestCredentialMessage}.
     *
     * @param options
     * @returns The created {@link V2RequestCredentialMessage}
     *
     */
    createRequest({ credentialFormats, formatServices, credentialRecord, comment, }: {
        formatServices: CredentialFormatService[];
        credentialFormats: CredentialFormatPayload<CFs, 'createRequest'>;
        credentialRecord: CredentialExchangeRecord;
        comment?: string;
    }): Promise<V2RequestCredentialMessage>;
    processRequest({ credentialRecord, message, formatServices, }: {
        credentialRecord: CredentialExchangeRecord;
        message: V2RequestCredentialMessage;
        formatServices: CredentialFormatService[];
    }): Promise<void>;
    acceptRequest({ credentialRecord, credentialFormats, formatServices, comment, }: {
        credentialRecord: CredentialExchangeRecord;
        credentialFormats?: CredentialFormatPayload<CFs, 'acceptRequest'>;
        formatServices: CredentialFormatService[];
        comment?: string;
    }): Promise<V2IssueCredentialMessage>;
    processCredential({ credentialRecord, message, formatServices, }: {
        credentialRecord: CredentialExchangeRecord;
        message: V2IssueCredentialMessage;
        formatServices: CredentialFormatService[];
    }): Promise<void>;
    getAttachmentForService(credentialFormatService: CredentialFormatService, formats: CredentialFormatSpec[], attachments: Attachment[]): Attachment;
    private getAttachmentIdForService;
}
